pub struct Fill {
pub style: FillStyle,
pub rule: FillRule,
}Expand description
The style used to fill geometry.
Fields
style: FillStyleThe color or gradient of the fill.
By default, it is set to FillStyle::Solid with [Color::BLACK].
rule: FillRuleThe fill rule defines how to determine what is inside and what is outside of a shape.
See the SVG specification for more details.
By default, it is set to NonZero.