pub struct Path {
pub raw: Path,
}Expand description
An immutable set of points that may or may not be connected.
A single Path can represent different kinds of 2D shapes!
Fields
raw: PathImplementations
Sourceimpl Path
impl Path
pub fn builder() -> PathBuilder
Sourcepub fn line(from: Point, to: Point) -> Self
pub fn line(from: Point, to: Point) -> Self
Creates a new Path representing a line segment given its starting
and end points.
Sourcepub fn rectangle(top_left: Point, size: Size) -> Self
pub fn rectangle(top_left: Point, size: Size) -> Self
Creates a new Path representing a rectangle given its top-left
corner coordinate and its Size.