Stroke

Struct Stroke 

pub struct Stroke<'a> {
    pub style: FillStyle,
    pub width: f32,
    pub line_cap: LineCap,
    pub line_join: LineJoin,
    pub line_dash: LineDash<'a>,
}
The style of a stroke.

Fields

style: FillStyle

The color or gradient of the stroke.

By default, it is set to a [Style::Solid] with [Color::BLACK].

width: f32

The distance between the two edges of the stroke.

line_cap: LineCap

The shape to be used at the end of open subpaths when they are stroked.

line_join: LineJoin

The shape to be used at the corners of paths or basic shapes when they are stroked.

line_dash: LineDash<'a>

The dash pattern used when stroking the line.

Implementations

Source

impl<'a> Stroke<'a>

pub fn with_color(self, color: PackedSrgb) -> Self

Sets the color of the Stroke.

pub fn with_width(self, width: f32) -> Self

Sets the width of the Stroke.

pub fn with_line_cap(self, line_cap: LineCap) -> Self

Sets the LineCap of the Stroke.

pub fn with_line_join(self, line_join: LineJoin) -> Self

Sets the LineJoin of the Stroke.